require "pretzel/orm"
require "bcrypt"

module Pretzel
  module Accounts

    begin
      connection = Pretzel::ORM.all_connections[0] # Grab the first initialized connection.
      connection.create_table? :pretzel_users do
        primary_key :id
        string :name
        string :email
        string :salt
        string :password

        unique :name
      end

      class User < Pretzel::ORM::Model
        set_dataset :pretzel_users # Set table name
        exposes :id, :name, :email # Expose attributes to Liquid

        def before_save
          self.salt = BCrypt::Engine.generate_salt # Make salt
          self.password = BCrypt::Engine.hash_secret(self.password, self.salt) # Hash password
        end

        def authenticate?(password)
          if self.password == BCrypt::Engine.hash_secret(password, self.salt)
            true
          else
            false
          end
        end        
      end
    rescue Sequel::Error
      puts "ERROR: Establish a database connection BEFORE requiring pretzel-accounts."
    end

    module Route
      def self.included(application)
      end

      def requires_authentication
        halt 401 unless !!session[:user]
      end

      def login(user)
        session[:user] = user[:id]
      end
    end

  end
end